import sys
import os
import requests

file_path = os.path.abspath(__file__)
end = file_path.index('mns') + 14
project_path = file_path[0:end]
sys.path.append(project_path)
import pandas as pd
import mns_common.utils.data_frame_util as data_frame_util

BEST_CHOOSE = '7'
AREA = '6'
CONCEPT = '5'
INDUSTRY = '4'

PAGE_MAX_COUNT = 80

HIS_PAGE_MAX_COUNT = 70


# index_type= 4 行业   index_type= 5 概念  index_type= 6 地域 ndex_type= 7 精选板块
def get_plate_index(index_type):
    result = pd.DataFrame()
    page_number = 0
    page_index = 0
    headers = {
        "User-Agent": "Content-Type: application/x-www-form-urlencoded; charset=utf-8"
    }
    while True:
        r = requests.post("https://apphq.longhuvip.com/w1/api/index.php?"
                          "Index=" + str(page_index) + "&Order=1&PhoneOSNew=2&Type=1&VerSion=5.13.0.3&ZSType="
                          + str(index_type) +
                          "&a=RealRankingInfo&apiv=w35&c=ZhiShuRanking&st="
                          + str(PAGE_MAX_COUNT), headers=headers)

        data_json = r.json()
        data_concept = data_json['list']
        data_df = pd.DataFrame(data_concept)
        if data_frame_util.is_empty(data_df):
            break
        data_df.columns = [
            "plate_code",
            "plate_name",
            "heat_score",
            "chg",
            "speed",
            "amount",
            "main_net_inflow",
            "main_inflow_in",
            "main_inflow_out",
            "quantity_ratio",
            "flow_mv",
            "-",
            "super_order_net",
            "total_mv",
            "last_reason_organ_add",
            "ava_pe_now",
            "ava_pe_next",
            "-",
            "-"
        ]
        data_df = data_df[[
            "plate_code",
            "plate_name",
            "heat_score",
            "chg",
            "speed",
            "amount",
            "main_net_inflow",
            "main_inflow_in",
            "main_inflow_out",
            "quantity_ratio",
            "flow_mv",
            "super_order_net",
            "total_mv",
            "last_reason_organ_add",
            "ava_pe_now",
            "ava_pe_next"
        ]]
        result = pd.concat([result, data_df])
        if data_df.shape[0] < PAGE_MAX_COUNT:
            break
        else:
            page_number = page_number + 1
            page_index = page_number * PAGE_MAX_COUNT

    return result


# 板块股票组成# 精选板块 # 行业板块

# Order 排序参数
# st 分页最大数量
# index 股票排名index
def plate_detail_info(plate_code):
    index = 0
    result = None
    while True:
        url = (
                f"https://apphq.longhuvip.com/w1/api/index.php?"
                f"Index=" + str(index) +
                f"&IsKZZType=0"
                f"&IsZZ=0"
                f"&Order=1"
                f"&PhoneOSNew=3"
                f"&PlateID=" + str(plate_code) +
                f"&Token=e4b1267830dc99626a1e95394980d769&Type=6&UserID=2289803"
                f"&VerSion=5.11.0.3&a=ZhiShuStockList_W8&apiv=w33&c=ZhiShuRanking"
                f"&old=1&st=100")
        headers = {
            "User-Agent": "Content-Type: application/x-www-form-urlencoded; charset=utf-8"
        }
        r = requests.post(url, headers=headers)
        data_json = r.json()
        data_concept = data_json['list']
        count = data_json['Count']
        data_df = pd.DataFrame(data_concept)
        result = data_frame_util.merge_choose_data_no_drop(result, data_df)
        index = index + 100
        if count < index:
            break
    if data_frame_util.is_empty(result):
        return None
    result.columns = [
        'symbol',
        'name',
        'you_zi',
        '_',
        'plate_name_list',
        'now_price',
        'chg',
        'amount',
        'exchange',
        'speed',
        'real_flow_mv',
        'main_flow_in',
        'main_flow_out',
        'main_flow_net',
        '_',
        '_',
        '_',
        '_',
        '_',
        # 卖流占比
        'sell_radio',
        '_',
        'chg_from_chg',
        '_',
        'connected_boards',
        'dragon_index',
        '_',
        '_',
        '_',
        'closure_funds',
        'max_closure_funds',
        '_',
        '_',
        '_',
        '_',
        '_',
        '_',
        '_',
        'total_mv',
        'flow_mv',
        'most_relative_name',
        '_',
        '_',
        '_',
        '_',

        '_',
        '_',
        '_',
        '_',
        '_',
        '_',

        '_',
        '_',

        '_',
        '_',

        '_',
        '_',
        '_',
        '_',
        '_',
        '_'

    ]
    return result


# 历史区间强度

# begin到end之间的强度
def get_plate_index_his(index, index_type, str_day, begin, end):
    url = "https://apphis.longhuvip.com/w1/api/index.php?Date" \
          "=" + str(str_day) + \
          "&Index=" + str(index) + \
          "&Order=1&PhoneOSNew=2" \
          "&REnd=" + str(end) + \
          "&RStart=" + str(begin) + \
          "&Type=1&VerSion=5.14.0.1" \
          "&ZSType=" + str(index_type) + \
          "&a=RealRankingInfo&apiv=w36&c=ZhiShuRanking" \
          "&st=" + str(HIS_PAGE_MAX_COUNT)

    headers = {
        "User-Agent": "Content-Type: application/x-www-form-urlencoded; charset=utf-8"
    }
    r = requests.post(url, headers=headers)
    data_json = r.json()
    data_concept = data_json['list']
    data_df_his = pd.DataFrame(data_concept)
    if data_frame_util.is_empty(data_df_his):
        return None
    data_df_his.columns = [
        "plate_code",
        "plate_name",
        "heat_score",
        "chg",
        "speed",
        "amount",
        "main_net_inflow",
        "main_inflow_in",
        "main_inflow_out",
        "quantity_ratio",
        "flow_mv",
        "-",
        "super_order_net",
        "total_mv",
        "last_reason_organ_add",
        "ava_pe_now",
        "ava_pe_next",
        "-",
        "-"
    ]
    return data_df_his


if __name__ == '__main__':
    df = get_plate_index(7)
    # while True:
    #     df = get_plate_index(5)
    #     print(df)
    data_df = get_plate_index_his(0, 7, '2024-04-24', '0925', '0930')
    print(data_df)



import sys
import os

file_path = os.path.abspath(__file__)
end = file_path.index('mns') + 16
project_path = file_path[0:end]
sys.path.append(project_path)
import mns_common.utils.data_frame_util as data_frame_util
from mns_common.component.classify.symbol_classify_param import stock_type_classify_param


# 深沪普通股票  选择 10cm涨幅的
def choose_sh_symbol(realtime_quotes_now):
    return realtime_quotes_now.loc[
        (realtime_quotes_now['classification'].isin(['S', 'H']))]


# 选择科创 创业板 20厘米的
def choose_kc_symbol(realtime_quotes_now):
    return realtime_quotes_now.loc[
        realtime_quotes_now['classification'].isin(['K', 'C'])]


# 选择北交所的 30厘米的
def choose_bjs_symbol(realtime_quotes_now):
    return realtime_quotes_now.loc[
        realtime_quotes_now['classification'].isin(['X'])]


# 设置新股次新标记
def set_stock_type(real_time_quotes_now_init):
    if data_frame_util.is_empty(real_time_quotes_now_init):
        return None
    real_time_quotes_now = real_time_quotes_now_init.copy()
    real_time_quotes_now.loc[:, "stock_type"] = stock_type_classify_param['normal_stock']
    # 上市五个交易日的股票
    real_time_quotes_now.loc[real_time_quotes_now['name'].str.startswith('C'), "stock_type"] = \
        stock_type_classify_param[
            'new_stock']
    # 交易上市6-70天的次新股票
    real_time_quotes_now.loc[
        (real_time_quotes_now['stock_type'] != stock_type_classify_param['new_stock'])
        & (real_time_quotes_now['deal_days'] <= stock_type_classify_param['sub_stock_new_max_deal_days']),
        "stock_type"] = stock_type_classify_param['sub_stock_new']

    # 上市次新股 70-365
    real_time_quotes_now.loc[
        (real_time_quotes_now['deal_days'] >= stock_type_classify_param['sub_stock_new_max_deal_days'])
        & (real_time_quotes_now['deal_days'] <= stock_type_classify_param['sub_stock_max_days']),
        "stock_type"] = stock_type_classify_param['sub_stock']

    return real_time_quotes_now


# 新上市注册股票
def choose_new_stock(real_time_quotes_now):
    real_time_quotes_now = real_time_quotes_now.loc[
        real_time_quotes_now['stock_type'] == stock_type_classify_param['new_stock']]

    return real_time_quotes_now


# 排除新股
def exclude_new_stock(real_time_quotes_now):
    real_time_quotes_now = real_time_quotes_now.loc[
        real_time_quotes_now['stock_type'] != stock_type_classify_param['new_stock']]
    return real_time_quotes_now


# 选择次新new     # 交易上市6-70天的次新股票
def choose_sub_new(real_time_quotes_now):
    real_time_quotes_now = real_time_quotes_now.loc[
        real_time_quotes_now['stock_type'] == stock_type_classify_param['sub_stock_new']]

    return real_time_quotes_now


# 排除次新new      # 交易上市6-70天的次新股票
def exclude_sub_new(real_time_quotes_now):
    real_time_quotes_now = real_time_quotes_now.loc[
        real_time_quotes_now['stock_type'] != stock_type_classify_param['sub_stock_new']]
    return real_time_quotes_now


# 选择次新 71-365
def choose_sub_stock(real_time_quotes_now):
    real_time_quotes_now = real_time_quotes_now.loc[
        real_time_quotes_now['stock_type'] == stock_type_classify_param['sub_stock']]

    return real_time_quotes_now


# 排除次新  71-365
def exclude_sub_stock(real_time_quotes_now):
    real_time_quotes_now = real_time_quotes_now.loc[
        real_time_quotes_now['stock_type'] != stock_type_classify_param['sub_stock']]
    return real_time_quotes_now


# 选择普通
def choose_normal_stock(real_time_quotes_now):
    real_time_quotes_now = real_time_quotes_now.loc[
        real_time_quotes_now['stock_type'] == stock_type_classify_param['normal_stock']]

    return real_time_quotes_now


# 排除普通
def exclude_normal_stock(real_time_quotes_now):
    real_time_quotes_now = real_time_quotes_now.loc[
        real_time_quotes_now['stock_type'] != stock_type_classify_param['normal_stock']]
    return real_time_quotes_now


# 根据类型列表选择
def choose_stock_by_type_list(real_time_quotes_now, type_list):
    return real_time_quotes_now.loc[
        real_time_quotes_now['stock_type'].isin(type_list)]



# import sys
# import os
#
# file_path = os.path.abspath(__file__)
# end = file_path.index('mns') + 16
# project_path = file_path[0:end]
# sys.path.append(project_path)
# import time, datetime, traceback, sys
# from xtquant import xtdata
# from xtquant.xttrader import XtQuantTrader, XtQuantTraderCallback
# from xtquant.xttype import StockAccount
# from xtquant import xtconstant
#
# # 定义一个类 创建类的实例 作为状态的容器
# class _a():
#     pass
#
#
# A = _a()
# A.bought_list = []
# A.hsa = xtdata.get_stock_list_in_sector('沪深A股')
#
#
# def interact():
#     """执行后进入repl模式"""
#     import code
#     code.InteractiveConsole(locals=globals()).interact()
#
#
# xtdata.download_sector_data()
#
#
#
# class MyXtQuantTraderCallback(XtQuantTraderCallback):
#     def on_disconnected(self):
#         """
#         连接断开
#         :return:
#         """
#         print(datetime.datetime.now(), '连接断开回调')
#
#     def on_stock_order(self, order):
#         """
#         委托回报推送
#         :param order: XtOrder对象
#         :return:
#         """
#         print(datetime.datetime.now(), '委托回调 投资备注', order.order_remark)
#
#     def on_stock_trade(self, trade):
#         """
#         成交变动推送
#         :param trade: XtTrade对象
#         :return:
#         """
#         print(datetime.datetime.now(), '成交回调', trade.order_remark, f"委托方向(48买 49卖) {trade.offset_flag} 成交价格 {trade.traded_price} 成交数量 {trade.traded_volume}")
#
#     def on_order_error(self, order_error):
#         """
#         委托失败推送
#         :param order_error:XtOrderError 对象
#         :return:
#         """
#         # print("on order_error callback")
#         # print(order_error.order_id, order_error.error_id, order_error.error_msg)
#         print(f"委托报错回调 {order_error.order_remark} {order_error.error_msg}")
#
#     def on_cancel_error(self, cancel_error):
#         """
#         撤单失败推送
#         :param cancel_error: XtCancelError 对象
#         :return:
#         """
#         print(datetime.datetime.now(), sys._getframe().f_code.co_name)
#
#     def on_order_stock_async_response(self, response):
#         """
#         异步下单回报推送
#         :param response: XtOrderResponse 对象
#         :return:
#         """
#         print(f"异步委托回调 投资备注: {response.order_remark}")
#
#     def on_cancel_order_stock_async_response(self, response):
#         """
#         :param response: XtCancelOrderResponse 对象
#         :return:
#         """
#         print(datetime.datetime.now(), sys._getframe().f_code.co_name)
#
#     def on_account_status(self, status):
#         """
#         :param response: XtAccountStatus 对象
#         :return:
#         """
#         print(datetime.datetime.now(), sys._getframe().f_code.co_name)
#
#
# if __name__ == '__main__':
#     if __name__ == '__main__':
#         print("start")
#         # 指定客户端所在路径, 券商端指定到 userdata_mini文件夹
#         # 注意：如果是连接投研端进行交易，文件目录需要指定到f"{安装目录}\userdata"
#         path = r'D:\Program Files\qmt\国金证券QMT交易端\userdata_mini'
#         # 生成session id 整数类型 同时运行的策略不能重复
#         session_id = int(time.time())
#         xt_trader = XtQuantTrader(path, session_id)
#         # 开启主动请求接口的专用线程 开启后在on_stock_xxx回调函数里调用XtQuantTrader.query_xxx函数不会卡住回调线程，但是查询和推送的数据在时序上会变得不确定
#         # 详见: http://docs.thinktrader.net/vip/pages/ee0e9b/#开启主动请求接口的专用线程
#         # xt_trader.set_relaxed_response_order_enabled(True)
#
#         # 创建资金账号为 800068 的证券账号对象 股票账号为STOCK 信用CREDIT 期货FUTURE
#         acc = StockAccount('8882352999', 'STOCK')
#         # 创建交易回调类对象，并声明接收回调
#         callback = MyXtQuantTraderCallback()
#         xt_trader.register_callback(callback)
#         # 启动交易线程
#         xt_trader.start()
#         # 建立交易连接，返回0表示连接成功
#         connect_result = xt_trader.connect()
#         print('建立交易连接，返回0表示连接成功', connect_result)
#         # 对交易回调进行订阅，订阅后可以收到交易主推，返回0表示订阅成功
#         subscribe_result = xt_trader.subscribe(acc)
#         print('对交易回调进行订阅，订阅后可以收到交易主推，返回0表示订阅成功', subscribe_result)
#         # 取账号信息
#         account_info = xt_trader.query_stock_asset(acc)
#         # 取可用资金
#         available_cash = account_info.m_dCash
#
#         print(acc.account_id, '可用资金', available_cash)
#         # 查账号持仓
#         positions = xt_trader.query_stock_positions(acc)
#         # 取各品种 总持仓 可用持仓
#         position_total_dict = {i.stock_code: i.m_nVolume for i in positions}
#         position_available_dict = {i.stock_code: i.m_nCanUseVolume for i in positions}
#         print(acc.account_id, '持仓字典', position_total_dict)
#         print(acc.account_id, '可用持仓字典', position_available_dict)
#
#         # 买入 浦发银行 最新价 两万元
#         stock = '600000.SH'
#         target_amount = 20000
#         full_tick = xtdata.get_full_tick([stock])
#         print(f"{stock} 全推行情： {full_tick}")
#         current_price = full_tick[stock]['lastPrice']
#         # 买入金额 取目标金额 与 可用金额中较小的
#         buy_amount = min(target_amount, available_cash)
#         # 买入数量 取整为100的整数倍
#         buy_vol = int(buy_amount / current_price / 100) * 100
#         print(f"当前可用资金 {available_cash} 目标买入金额 {target_amount} 买入股数 {buy_vol}股")
#         async_seq = xt_trader.order_stock_async(acc, stock, xtconstant.STOCK_BUY, buy_vol, xtconstant.FIX_PRICE,
#                                                 current_price,
#                                                 'strategy_name', stock)
#
#         # 卖出 500股
#         stock = '513130.SH'
#         # 目标数量
#         target_vol = 500
#         # 可用数量
#         available_vol = position_available_dict[stock] if stock in position_available_dict else 0
#         # 卖出量取目标量与可用量中较小的
#         sell_vol = min(target_vol, available_vol)
#         print(f"{stock} 目标卖出量 {target_vol} 可用数量 {available_vol} 卖出 {sell_vol}股")
#         if sell_vol > 0:
#             async_seq = xt_trader.order_stock_async(acc, stock, xtconstant.STOCK_SELL, sell_vol,
#                                                     xtconstant.LATEST_PRICE,
#                                                     -1,
#                                                     'strategy_name', stock)
#         print(f"下单完成 等待回调")
#         # 阻塞主线程退出
#         # xt_trader.run_forever()
#         # 如果使用vscode pycharm等本地编辑器 可以进入交互模式 方便调试 （把上一行的run_forever注释掉 否则不会执行到这里）
#         interact()


import sys
import os

file_path = os.path.abspath(__file__)
end = file_path.index('mns') + 16
project_path = file_path[0:end]
sys.path.append(project_path)
from mns_common.db.MongodbUtil import MongodbUtil

mongodb_util = MongodbUtil('27017')
import mns_common.constant.db_name_constant as db_name_constant
from functools import lru_cache


# 获取自选板块信息
@lru_cache(maxsize=None)
def get_self_choose_plate_list():
    return mongodb_util.find_all_data(db_name_constant.SELF_CHOOSE_PLATE)



import sys
import os

file_path = os.path.abspath(__file__)
end = file_path.index('mns') + 14
project_path = file_path[0:end]
sys.path.append(project_path)

import requests
import pandas as pd
import mns_common.utils.data_frame_util as data_frame_util
from loguru import logger


def stock_board_concept_name_em() -> pd.DataFrame:
    """
    东方财富网-行情中心-沪深京板块-概念板块-名称
    https://quote.eastmoney.com/center/boardlist.html#concept_board
    :return: 概念板块-名称
    :rtype: pandas.DataFrame
    """
    url = "http://79.push2.eastmoney.com/api/qt/clist/get"
    params = {
        "pn": "1",
        "pz": "2000",
        "po": "1",
        "np": "1",
        "ut": "bd1d9ddb04089700cf9c27f6f7426281",
        "fltt": "2",
        "invt": "2",
        "fid": "f3",
        "fs": "m:90 t:3 f:!50",
        "fields": "f2,f3,f4,f8,f12,f14,f15,f16,f17,f18,f20,f21,f24,f25,f22,f26,f33,f11,f62,f128,f124,f107,f104,f105,f136",
        "_": "1626075887768",
    }
    r = requests.get(url, params=params)
    data_json = r.json()
    temp_df = pd.DataFrame(data_json["data"]["diff"])
    temp_df.reset_index(inplace=True)
    temp_df["index"] = range(1, len(temp_df) + 1)
    temp_df.columns = [
        "排名",
        "最新价",
        "涨跌幅",
        "涨跌额",
        "换手率",
        "_",
        "板块代码",
        "板块名称",
        "_",
        "_",
        "_",
        "_",
        "总市值",
        "_",
        "_",
        "_",
        "_",
        "新增日期",
        "_",
        "_",
        "上涨家数",
        "下跌家数",
        "_",
        "_",
        "领涨股票",
        "_",
        "_",
        "领涨股票-涨跌幅",
    ]
    temp_df = temp_df[
        [
            "排名",
            "板块名称",
            "板块代码",
            "最新价",
            "涨跌额",
            "涨跌幅",
            "总市值",
            "换手率",
            "新增日期",
            "上涨家数",
            "下跌家数",
            "领涨股票",
            "领涨股票-涨跌幅",
        ]
    ]
    temp_df["最新价"] = pd.to_numeric(temp_df["最新价"], errors="coerce")
    temp_df["涨跌额"] = pd.to_numeric(temp_df["涨跌额"], errors="coerce")
    temp_df["涨跌幅"] = pd.to_numeric(temp_df["涨跌幅"], errors="coerce")
    temp_df["总市值"] = pd.to_numeric(temp_df["总市值"], errors="coerce")
    temp_df["换手率"] = pd.to_numeric(temp_df["换手率"], errors="coerce")
    temp_df["上涨家数"] = pd.to_numeric(temp_df["上涨家数"], errors="coerce")
    temp_df["下跌家数"] = pd.to_numeric(temp_df["下跌家数"], errors="coerce")
    temp_df["领涨股票-涨跌幅"] = pd.to_numeric(temp_df["领涨股票-涨跌幅"], errors="coerce")
    return temp_df


# 同步所有概念
def sync_all_concept():
    try:
        stock_board_concept_name_em_df = stock_board_concept_name_em()
        stock_board_concept_name_em_df = stock_board_concept_name_em_df.rename(columns={"排名": "index",
                                                                                        "板块名称": "concept_name",
                                                                                        "板块代码": "concept_code",
                                                                                        "最新价": "now_price",
                                                                                        "涨跌额": "change",
                                                                                        "涨跌幅": "chg",
                                                                                        "总市值": "total_mv",
                                                                                        "换手率": "exchange",
                                                                                        "新增日期": "list_day",
                                                                                        "上涨家数": "up_number",
                                                                                        "下跌家数": "down_number",
                                                                                        "领涨股票": "up_header",
                                                                                        "领涨股票-涨跌幅": "up_header_chg"
                                                                                        })
        return stock_board_concept_name_em_df
    except BaseException as e:
        logger.error("同步东方财富概念信息异常:{}", e)
        return None


def stock_board_concept_cons_em(stock_board_code: str = "BK1134") -> pd.DataFrame:
    """
    东方财富-沪深板块-概念板块-板块成份
    https://quote.eastmoney.com/center/boardlist.html#boards-BK06551
    :param symbol: 板块名称
    :type symbol: str
    :return: 板块成份
    :rtype: pandas.DataFrame
    """

    url = "http://29.push2.eastmoney.com/api/qt/clist/get"
    params = {
        "pn": "1",
        "pz": "2000",
        "po": "1",
        "np": "1",
        "ut": "bd1d9ddb04089700cf9c27f6f7426281",
        "fltt": "2",
        "invt": "2",
        "fid": "f3",
        "fs": f"b:{stock_board_code} f:!50",
        "fields": "f1,f2,f3,f4,f5,f6,f7,f8,f9,f10,f12,f13,f14,f15,f16,f17,f18,f20,f21,f23,f24,f25,f22,f11,f62,f128,f136,f115,f152,f45",
        "_": "1626081702127",
    }
    r = requests.get(url, params=params)
    data_json = r.json()
    data_df = pd.DataFrame(data_json["data"])
    if data_frame_util.is_empty(data_df):
        return None
    temp_df_copy = pd.DataFrame(data_json["data"]["diff"])
    temp_df_copy.reset_index(inplace=True)
    temp_df_copy["index"] = range(1, len(temp_df_copy) + 1)
    temp_df_copy.columns = [
        "序号",
        "_",
        "最新价",
        "涨跌幅",
        "涨跌额",
        "成交量",
        "成交额",
        "振幅",
        "换手率",
        "市盈率-动态",
        "_",
        "_",
        "代码",
        "_",
        "名称",
        "最高",
        "最低",
        "今开",
        "昨收",
        "_",
        "_",
        "_",
        "市净率",
        "_",
        "_",
        "_",
        "_",
        "_",
        "_",
        "_",
        "_",
        "_",
        "_",
    ]
    temp_df_copy = temp_df_copy[
        [
            "序号",
            "代码",
            "名称",
            "最新价",
            "涨跌幅",
            "涨跌额",
            "成交量",
            "成交额",
            "振幅",
            "最高",
            "最低",
            "今开",
            "昨收",
            "换手率",
            "市盈率-动态",
            "市净率",
        ]
    ]
    temp_df = temp_df_copy.copy()

    temp_df["最新价"] = pd.to_numeric(temp_df["最新价"], errors="coerce")
    temp_df["涨跌幅"] = pd.to_numeric(temp_df["涨跌幅"], errors="coerce")
    temp_df["涨跌额"] = pd.to_numeric(temp_df["涨跌额"], errors="coerce")
    temp_df["成交量"] = pd.to_numeric(temp_df["成交量"], errors="coerce")
    temp_df["成交额"] = pd.to_numeric(temp_df["成交额"], errors="coerce")
    temp_df["振幅"] = pd.to_numeric(temp_df["振幅"], errors="coerce")
    temp_df["最高"] = pd.to_numeric(temp_df["最高"], errors="coerce")
    temp_df["最低"] = pd.to_numeric(temp_df["最低"], errors="coerce")
    temp_df["今开"] = pd.to_numeric(temp_df["今开"], errors="coerce")
    temp_df["昨收"] = pd.to_numeric(temp_df["昨收"], errors="coerce")
    temp_df["换手率"] = pd.to_numeric(temp_df["换手率"], errors="coerce")
    temp_df["市盈率-动态"] = pd.to_numeric(temp_df["市盈率-动态"], errors="coerce")
    temp_df["市净率"] = pd.to_numeric(temp_df["市净率"], errors="coerce")
    return temp_df


if __name__ == '__main__':
    df = stock_board_concept_cons_em()
    print(df)
